---
title: Barcode
page_title: Overview - Barcode - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI Barcode wrapper for Vue delivers and use the component in Vue projects."
slug: overview_barcode
position: 1
---

# Barcode Overview

Barcodes represent data in a machine-readable format and support [symbologies](https://docs.telerik.com/kendo-ui/controls/barcodes/barcode/encodings#supported-symbologies).

All graphics are rendered on the client in a [Scalable Vector Graphics (SVG)](https://www.w3.org/Graphics/SVG/) format.

The Barcode wrapper for Vue is a client-side wrapper for the [Kendo UI Barcode](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/barcode) widget.

## Basic Usage

The following example demonstrates the Barcode in action.

```html-preview
<div id="vueapp" class="vue-app">
	<kendo-barcode :value="2346722"
				   :type="'ean8'"
				   :width="280"
				   :height="100">
	</kendo-barcode>
    <kendo-barcode :value="barcodeValue"
				   :width="280"
				   :height="100">
	</kendo-barcode>
    <h4>Enter a number:</h4>
	<kendo-numerictextbox type="number"
                          title="number"
                          :value="100000"
                          :min="0"
                          :max="10000000000000"
						  v-model="barcodeValue"
                          :format="'n0'">
    </kendo-numerictextbox>
</div>
```
```js
Vue.use(BarcodesInstaller);
Vue.use(InputsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            barcodeValue: 1234
        }
    }
})
```

## Suggested Links

* [Kendo UI Barcode for jQuery](https://docs.telerik.com/kendo-ui/controls/barcodes/barcode/overview)
* [API Reference of the Barcode Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/barcode)
